Glossary
-----------

.. glossary::

   profile
      Customization for each HaFAS deployment
      - Contains the endpoint, tokens and possible changes for the deployment

   FPTF
      Abbreviation for `Friendly Public Transport Format <https://github.com/public-transport/friendly-public-transport-format/blob/master/spec/readme.md>`_
      - Used as the basis for returned data

   Station Board
      Generalization for :func:`arrivals <pyhafas.client.HafasClient.arrivals>` and :func:`departures <pyhafas.client.HafasClient.departures>` requests

   product
      A product is the generalization of all means of transport. When this term is used, all types of transport are meant (e.g. busses, regional trains, ferries).

   journey
      A journey is a computed set of directions to get from A to B at a specific time. It would typically be the result of a route planning algorithm.

   leg
      A leg or also named trip is most times part of a journey and defines a journey with only one specific vehicle from A to B.
